@@ -6,13 +6,13 @@ import re
 
 __RE_STAGE__ = "__RE_STAGE__"
 __QA_STAGE__ = "__QA_STAGE__"
-__Similarly_Stage__ = "__Similarly_Stage__"
+__Similarly_STAGE__ = "__Similarly_STAGE__"
 __SWITCH_STAGE__ = StageType.SWITCH
 __LIB_SWITCH_STAGE__ = "__LIB_SWITCH_STAGE__"
 __Classify_STAGE__ = "__Classify_STAGE__"
 
 #
-__QUESTIONS_LABEL__ = ["__SYS_QUESTION__", "question", "says"]
+__QUESTIONS_LABEL__ = ["__SYS_QUESTION__", "question", "says", "corpus"]
 __WELCOME_SAYING_LABELS__ = ["__SYS_WELCOME__", "sys_reply_q1", "sys_welcome"]
 __REFUSE_SAYING_LABELS__ = ["__SYS_REFUSE__", "sys_reply_q2", "sys_refuse"]
 __COMPLETE_SAYING_LABELS__ = ["__SYS_COMPLETE__", "sys_reply_complete", "sys_complete"]
@@ -23,17 +23,17 @@ from .nlp_tool import similar
 
 
 class QAStage(Stage):
-    __QA_RESPOND__ = "__QA_RESPOND__"
-    __QA_RESPOND_SCORE__ = "__QA_RESPOND_SCORE__"
-    __QA_RESPOND_QUESTION__ = "__QA_RESPOND_QUESTION__"
-    __QA_RESPOND_THRESHOLD__ = "__QA_RESPOND_THRESHOLD__"
+    __QA_RESPOND__ = ["__QA_RESPOND__"]
+    __QA_RESPOND_SCORE__ = ["__QA_RESPOND_SCORE__"]
+    __QA_RESPOND_QUESTION__ = ["__QA_RESPOND_QUESTION__"]
+    __QA_RESPOND_THRESHOLD__ = ["__QA_RESPOND_THRESHOLD__"]
     __QA_THRESHOLD__ = "qa_threshold"
     __IS_FITS__ = "is_fits"
     __SAVED_NAME__ = "__SAVED_NAME__"
     __CORPUS__ = "corpus"
     __QUESTIONS__ = "question"
     __SIMILAR_METHOD__ = "similar_method"
-    __RUNNING_CORPUS__ = "__RUNNING_CORPUS__"
+    __RUNNING_CORPUS__ = ["__RUNNING_CORPUS__"]
     __DISSABLE_Q1__ = "__DISSABLE_Q1__"
     __REFACTOR_QUESTION__ = "refactor_questions"
 
@@ -92,11 +92,21 @@ class QAStage(Stage):
         best_res_responds = self.corpus[best_res_content] if best_res_content in self.corpus else None
 
         ##
-        __RUNNING_CORPUS__ = self.saved_name.get(self.__RUNNING_CORPUS__, self.__RUNNING_CORPUS__)
-        __QA_RESPOND__ = self.saved_name.get(self.__QA_RESPOND__, self.__QA_RESPOND__)
-        __QA_RESPOND_QUESTION__ = self.saved_name.get(self.__QA_RESPOND_QUESTION__, self.__QA_RESPOND_QUESTION__)
-        __QA_RESPOND_SCORE__ = self.saved_name.get(self.__QA_RESPOND_SCORE__, self.__QA_RESPOND_SCORE__)
-        __QA_RESPOND_THRESHOLD__ = self.saved_name.get(self.__QA_RESPOND_THRESHOLD__, self.__QA_RESPOND_THRESHOLD__)
+        __RUNNING_CORPUS__ = get_value_from_dict_by_multi_name(d=self.saved_name, names=self.__RUNNING_CORPUS__,
+                                                               default=self.__RUNNING_CORPUS__[0])
+
+
+        __QA_RESPOND__ = get_value_from_dict_by_multi_name(d=self.saved_name, names=self.__QA_RESPOND__,
+                                                           default=self.__QA_RESPOND__[0])
+        __QA_RESPOND_QUESTION__ = get_value_from_dict_by_multi_name(d=self.saved_name,
+                                                                    names=self.__QA_RESPOND_QUESTION__,
+                                                                    default=self.__QA_RESPOND_QUESTION__[0])
+        __QA_RESPOND_SCORE__ = get_value_from_dict_by_multi_name(d=self.saved_name,
+                                                                 names=self.__QA_RESPOND_SCORE__,
+                                                                 default=self.__QA_RESPOND_SCORE__[0])
+        __QA_RESPOND_THRESHOLD__ = get_value_from_dict_by_multi_name(d=self.saved_name,
+                                                                 names=self.__QA_RESPOND_THRESHOLD__,
+                                                                 default=self.__QA_RESPOND_THRESHOLD__[0])
 
         #
         kwargs = self.set_default_var(kwargs, __RUNNING_CORPUS__, corpus)
@@ -277,7 +287,9 @@ class ClassifyStage(REStage):
     __SAVE_Classify_Best__ = "__SAVE_Classify_Best__"
     __SAVE_Classify_result__ = "__SAVE_Classify_result__"
 
-    def get_classify_text(self, text, rules):
+    def get_classify_text(self, text, rules) -> dict:
+        # classify by RE-rule
+        # return likes: {"var_name_1":1.0,"var_name_2":0.3,"var_name_3":0.9}
         re_dict = {}
         for (rule, entity_name) in rules:
             entities = self.__get_entity__(rule, text)
@@ -332,7 +344,7 @@ __LIB_STAGES__ = {
     __QA_STAGE__: SimilarlyStage,
     __SWITCH_STAGE__: LibSwitchStage,
     __LIB_SWITCH_STAGE__: LibSwitchStage,
-    __Similarly_Stage__: SimilarlyStage,
+    __Similarly_STAGE__: SimilarlyStage,
     __Classify_STAGE__: ClassifyStage
 }
 
